# browser module defines functions for creating selenium webdriver
# objects. The way this works is selenium is a third-party library
# that gives a common interface for interacting with web browsers,
# i.e. chrome, firefox, internet explorer, and even a pseudo-browser.
#
# This library (selenium) creates a web browser process
# (chrome will actually fire up for you to see) and gives you
# a webdriver object interface to programmatically control the browser.
# You can do things like click on links, extract information from the
# page, pass control to a user... the limit is your imagination.

import selenium
import selenium.webdriver

class Browser:
    def __init__(self, ctx):
        self.ctx = ctx

    # This function has a parameter (driver) that passes in a value. In this case,
    # this driver variable defaults to the string 'chrome'. The code can call
    # create_webdriver() which is the same as create_webdriver('chrome') but
    # can alternatively call create_webdriver('firefox') and get different
    # functionality.
    def create_webdriver(self, driver='chrome'):
        if driver == 'chrome':
            return self.create_webdriver_chrome()
        elif driver == 'firefox':
            return self.create_webdriver_firefox()
        elif driver == 'phantom':
            return self.create_webdriver_phantom()
        else:
            log.LOGGER('browser').error('unable to handle webdriver request: %s' % driver)
            return

    def create_webdriver_firefox(self):
        profile = selenium.webdriver.FirefoxProfile()
        profile.set_preference(
            "general.useragent.override",
            self.ctx.config['app']['webdriver_user_agent'])
        driver = selenium.webdriver.Firefox(profile)
        return driver

    def create_webdriver_chrome(self):
        opt = selenium.webdriver.chrome.options.Options()
        opt.add_argument('--user-agent=' + self.ctx.config['app']['webdriver_user_agent'])
        driver = selenium.webdriver.Chrome(
            executable_path=self.ctx.config['app']['chromedriver_exe'],
            chrome_options=opt
        )
        return driver

    def create_webdriver_phantom(self):
        driver = selenium.webdriver.PhantomJS()
        return driver

